import { Token } from './tokenizer';
export interface File {
    type: 'File';
    body: BodyNode[];
}
export declare type BodyNode = Declaration | Include | Mapsize | MaterialExclusion | AutoVisGroup;
interface Declaration {
    type: 'Declaration';
    class: string;
    name: string;
    description?: Literal;
    parameters: Parameter[];
    body: DeclNode[];
}
export declare type DeclNode = Connection | SpawnFlags | Property;
export interface Parameter {
    type: 'Parameter';
    name: string;
    properties: (Name | Literal)[];
}
interface Name {
    type: 'Name';
    value: string;
}
interface Literal {
    type: 'Literal';
    value: string;
}
interface Connection {
    type: 'Connection';
    direction: string;
    name: string;
    args: string;
    description?: Literal;
}
interface SpawnFlags {
    type: 'SpawnFlags';
    flags: Flag[];
}
interface Property {
    type: 'Property';
    name: string;
    proptype: string;
    title: Literal;
    deflt: Literal;
    description: Literal;
    choices: Option[];
}
interface Include {
    type: 'Include';
    name: string;
}
interface Mapsize {
    type: 'Mapsize';
    x: number;
    y: number;
}
interface MaterialExclusion {
    type: 'MaterialExclusion';
    materials: string[];
}
interface AutoVisGroup {
    type: 'AutoVisGroup';
    description: string;
    categories: Category[];
}
interface Category {
    type: 'Category';
    name: string;
    groups: VisGroup[];
}
interface VisGroup {
    type: 'VisGroup';
    name: string;
}
interface Flag {
    type: 'Flag';
    value: Literal;
    title: Literal;
    enabled: Literal;
}
interface Option {
    type: 'Option';
    key: Literal;
    value: Literal;
}
export default function parser(tokens: Token[]): File;
export {};
