"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var RETURN = /\n/;
var WHITESPACE = /\s/;
var NAME = /[a-z_]/i;
var NUMBER = /[\-\d\.]/;
var SYMBOL = /[@,:=+]/;
function default_1(input) {
    var tokens = [];
    var current = 0;
    while (current < input.length) {
        var char = input[current];
        switch (true) {
            case SYMBOL.test(char):
                tokens.push({
                    type: 'symbol',
                    value: char,
                });
                current++;
                continue;
            case char === '(' || char === ')':
                tokens.push({
                    type: 'paren',
                    value: char,
                });
                current++;
                continue;
            case char === '[' || char === ']':
                tokens.push({
                    type: 'square',
                    value: char,
                });
                current++;
                continue;
            case char === '{' || char === '}':
                tokens.push({
                    type: 'bracket',
                    value: char,
                });
                current++;
                continue;
            case char === '"': {
                var value = '';
                char = input[++current];
                while (char !== '"') {
                    value += char;
                    char = input[++current];
                }
                tokens.push({
                    type: 'string',
                    value: value,
                });
                current++;
                continue;
            }
            case NAME.test(char): {
                var value = '';
                while (NAME.test(char) || NUMBER.test(char)) {
                    value += char;
                    char = input[++current];
                }
                tokens.push({
                    type: 'name',
                    value: value,
                });
                continue;
            }
            case NUMBER.test(char): {
                var value = '';
                while (NUMBER.test(char)) {
                    value += char;
                    char = input[++current];
                }
                tokens.push({
                    type: 'number',
                    value: Number(value),
                });
                continue;
            }
            case WHITESPACE.test(char):
                current++;
                continue;
            case char === '/': {
                char = input[++current];
                if (char !== '/') {
                    throw new TypeError("Unexpected character: " + char + " at position " + current);
                }
                char = input[++current];
                while (!RETURN.test(char)) {
                    char = input[++current];
                }
                while (RETURN.test(char)) {
                    char = input[++current];
                }
                continue;
            }
            default:
                throw new TypeError("Unknown character: " + char + " at position " + current);
        }
    }
    return tokens;
}
exports.default = default_1;
