"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function push(result, key, value) {
    if (result[key]) {
        // @ts-ignore
        result[key].push(value);
    }
    else {
        // @ts-ignore
        result[key] = [value];
    }
}
function param(result, param) {
    var parameters = result.parameters;
    if (!parameters) {
        parameters = {};
        result.parameters = parameters;
    }
    parameters[param.name] = param.properties.map(function (prop) { return prop.value; });
    return result;
}
function prop(result, decl) {
    switch (decl.type) {
        case 'Property': {
            var name_1 = decl.name, proptype = decl.proptype, title = decl.title, description = decl.description, deflt = decl.deflt;
            var prop_1 = {
                type: proptype,
                name: name_1,
            };
            if (title) {
                prop_1.title = title.value;
            }
            if (description) {
                prop_1.description = description.value;
            }
            if (deflt) {
                prop_1.deflt = deflt.value;
            }
            if (proptype === 'choices') {
                prop_1.choices = decl.choices.reduce(function (result, choice) {
                    result[choice.key.value] = choice.value.value;
                    return result;
                }, {});
            }
            push(result, 'properties', prop_1);
            break;
        }
        case 'Connection': {
            var name_2 = decl.name, description = decl.description, args = decl.args, direction = decl.direction;
            var conn = {
                name: name_2,
                description: description && description.value,
                type: args,
            };
            switch (direction) {
                case 'input':
                    push(result, 'inputs', conn);
                    break;
                case 'output':
                    push(result, 'outputs', conn);
                    break;
                default:
                    throw new TypeError("Unknown connection direction " + direction);
            }
            break;
        }
        case 'SpawnFlags':
            result.flags = decl.flags.map(function (_a) {
                var title = _a.title, value = _a.value, enabled = _a.enabled;
                return ({
                    title: title.value,
                    value: value.value,
                    enabled: !!enabled.value,
                });
            });
            break;
    }
    return result;
}
function decl(result, node) {
    if (node.type === 'Include') {
        console.info("You may also want to include " + node.name);
    }
    if (node.type === 'Declaration') {
        var decl_1 = {
            type: node.class,
        };
        if (node.description) {
            decl_1.description = node.description.value;
        }
        result[node.name] = node.body.reduce(prop, node.parameters.reduce(param, decl_1));
    }
    return result;
}
function transformer(ast) {
    return ast.body.reduce(decl, {});
}
exports.default = transformer;
